============
Installation
============

At the command line via pip::

    $ pip install abcpmc

This will install the package and all of the required dependencies. 

.. note:: If you wish to use `abcpmc` on a cluster with MPI you need to manually install `mpi4py <https://pypi.python.org/pypi/mpi4py>`_. 

